@@ -29,6 +29,7 @@ struct pl {
 
 extern const struct pl pl_null;
 
+struct pl *pl_alloc_str(const char *str);
 void     pl_set_str(struct pl *pl, const char *str);
 void     pl_set_mbuf(struct pl *pl, const struct mbuf *mb);
 int32_t  pl_i32(const struct pl *pl);
@@ -45,6 +46,7 @@ int      pl_strcpy(const struct pl *pl, char *str, size_t size);
 int      pl_strdup(char **dst, const struct pl *src);
 int      pl_dup(struct pl *dst, const struct pl *src);
 int      pl_strcmp(const struct pl *pl, const char *str);
+int      pl_strncmp(const struct pl *pl, const char *str, size_t n);
 int      pl_strcasecmp(const struct pl *pl, const char *str);
 int      pl_cmp(const struct pl *pl1, const struct pl *pl2);
 int      pl_casecmp(const struct pl *pl1, const struct pl *pl2);
@@ -178,9 +180,10 @@ static inline bool str_isset(const char *s)
 
 
 /* time */
-int  fmt_gmtime(struct re_printf *pf, void *ts);
-int  fmt_timestamp(struct re_printf *pf, void *ts);
-int  fmt_human_time(struct re_printf *pf, const uint32_t *seconds);
+int fmt_gmtime(struct re_printf *pf, void *ts);
+int fmt_timestamp(struct re_printf *pf, void *ts);
+int fmt_timestamp_us(struct re_printf *pf, void *arg);
+int fmt_human_time(struct re_printf *pf, const uint32_t *seconds);
 
 
 void hexdump(FILE *f, const void *p, size_t len);
@@ -201,3 +204,15 @@ void fmt_param_apply(const struct pl *pl, fmt_param_h *ph, void *arg);
 int utf8_encode(struct re_printf *pf, const char *str);
 int utf8_decode(struct re_printf *pf, const struct pl *pl);
 size_t utf8_byteseq(char u[4], unsigned cp);
+
+
+/* text2pcap */
+struct re_text2pcap {
+	bool in;
+	const struct mbuf *mb;
+	const char *id;
+};
+
+int re_text2pcap(struct re_printf *pf, struct re_text2pcap *pcap);
+void re_text2pcap_trace(const char *name, const char *id, bool in,
+			const struct mbuf *mb);
